@@ -37,6 +37,11 @@
 
 #include <SDL/SDL.h>
 
+#ifdef HILDON        
+#include <SDL/SDL_syswm.h>
+#include <X11/Xutil.h>
+#endif
+
 #include "2d_graph.h"
 
 // -------------------------------------------------------
@@ -474,7 +479,21 @@ SDL_Surface * graph_2d::create_screen(int flag, int width, int height, int bpp,
     fprintf(stderr, "unable to init SDL: %s", SDL_GetError());
     exit(0);
   }      
-        
+
+#ifdef HILDON        
+	// to set the title in the task bar
+  SDL_SysWMinfo info;
+  SDL_VERSION(&info.version);
+  if(SDL_GetWMInfo(&info)) {
+    Display *dpy = info.info.x11.display;
+    Window win;
+    win = info.info.x11.fswindow;
+    XStoreName(dpy, win, "Berusky");
+    win = info.info.x11.wmwindow;
+    XStoreName(dpy, win, "Berusky");
+  }
+#endif
+	
   flag |= SDL_HWSURFACE;
   
   if(fullscreen)
