@@ -640,10 +640,6 @@ public:
 
   graph_2d(tpos dx, tpos dy, int depth, bool fullscreen) : store(SURFACES, SPRITES), rect_last(0)
   {
-    /* sdl init */
-    bprintf("SDL Init...");
-    SDL_Init(SDL_INIT_VIDEO);
-
      /* Create new screen */
     bprintf("Seting up screen %dx%d, color depth %d bits, fullscreen = %d...",dx, dy, depth, fullscreen);
     create_screen(0, dx, dy, depth, fullscreen);
