@@ -201,6 +201,8 @@ void game_gui::menu_password(MENU_STATE state, int data, int data1)
 {
   #define MAX_PASSWORD 10
   static char password[MAX_PASSWORD] = "";
+  static int curLevelSet = 0;
+  static int curLevel = 0;
 
   switch(state) {
     case MENU_RETURN:
@@ -248,30 +250,71 @@ void game_gui::menu_password(MENU_STATE state, int data, int data1)
         bool character = key_to_ascii(data,&ascii_char);
         int  len = strlen(password);
       
-        if(character) {
-          if(len < MAX_PASSWORD-2) {
-            password[len] = ascii_char;
-            password[len+1] = '\0';
-          }        
-        } else {
-          switch(data) {
-            case K_BKSP:
-            case K_DEL:
-              if(len > 0) {
-                password[--len] = '\0';
+        switch(data) {
+#ifdef HILDON
+          case K_F7: // next level
+            {
+              // printf("F7: curLevelSet=%d, curLevel=%d\n", curLevelSet, curLevel);
+              p_ber->levelset_load(curLevelSet);
+              if((curLevel + 1) < p_ber->levelset_get_levelnum()) {
+                curLevel++;
+              } else if((curLevelSet + 1) < LEVELSET_NUM) {
+                curLevelSet++;
+                p_ber->levelset_load(curLevelSet);
+                curLevel = 0;
               }
-              break;
-            case K_ENTER:
-              break;
-            default:
-              break;
-          }
+              char * pw = p_ber->levelset_get_passwd(curLevel);
+              if(pw!=NULL)
+                strncpy(password,pw,MAX_PASSWORD-1);
+              password[MAX_PASSWORD-1] = '\0';
+            }
+            break;
+          case K_F8: // previous level
+            {
+              // printf("F7: curLevelSet=%d, curLevel=%d\n", curLevelSet, curLevel);
+              p_ber->levelset_load(curLevelSet);
+              if(curLevel > 0) {
+                curLevel--;
+              } else if(curLevelSet > 0) {
+                curLevelSet--;
+                p_ber->levelset_load(curLevelSet);
+                curLevel = p_ber->levelset_get_levelnum() - 1;
+              }
+              char * pw = p_ber->levelset_get_passwd(curLevel);
+              if(pw!=NULL)
+                strncpy(password,pw,MAX_PASSWORD-1);
+              password[MAX_PASSWORD-1] = '\0';
+            }
+            break;
+#endif
+          case K_BKSP:
+          case K_DEL:
+            if(len > 0) {
+              password[--len] = '\0';
+            }
+            break;
+          case K_ESC:
+          case K_ENTER:
+            break;
+          default:
+            // moved this code in here for meamo since some hardeare keys are interpreted as 'A'
+            if(character) {
+              if(len < MAX_PASSWORD-2) {
+                password[len] = ascii_char;
+                password[len+1] = '\0';
+              }        
+            }
+            break;
         }
       
         p_font->select(FONT_DEFAULT);
         p_font->alignment_set(CENTER);        
         p_grf->fill(0,INSERT_START+50,GAME_RESOLUTION_X,20,0);
+#ifdef HILDON
+        p_font->print(NULL, 0, INSERT_START+50, "(%s,%s) %s_", p_ber->levelset_get_difficulty(curLevelSet), p_ber->levelset_get_name(curLevel), password);
+#else
         p_font->print(NULL, 0, INSERT_START+50, "%s_", password);
+#endif
         p_grf->redraw_add(0,INSERT_START+50,GAME_RESOLUTION_X,20);
         p_grf->flip();
       }
